"""A collection of tools to gather and analyze knowledge from projects' repositories."""


__title__ = "srcopsmetrics"
__version__ = "2.9.1"
